@@ -9,5 +9,5 @@ class NullHandler(logging.Handler):
 
 
 # Configure default logger to do nothing
-log = logging.getLogger("iamzero_botocore")
-log.addHandler(NullHandler())
\ No newline at end of file
+# log = logging.getLogger("iamzero_botocore")
+# log.addHandler(NullHandler())
\ No newline at end of file
