@@ -165,7 +165,9 @@ class IAMZSerializer(object):
 
     def _serialize_data(self, data, event_dict, **kwargs):
         if data != b'':
-            event_dict["Data"] = data
+            # if `data` was a dict already, we wouldn't 
+            # need to deserialize it
+            event_dict["Data"] = json.loads(data)
 
     def _serialize_params(self, params, event_dict, **kwargs):
         event_dict["Params"] = params
